# Least Squares Module

The leastsq module contains least squares filter implementations.

::: bayesian_filters.leastsq
    options:
      show_root_heading: true
      show_source: false
      members: true
